import React from 'react';
import { useSelector, useDispatch } from 'react-redux'
import Box from '@mui/material/Box';
import Drawer from '@mui/material/Drawer';
import List from '@mui/material/List';
import ListItem from '@mui/material/ListItem';
import ListItemButton from '@mui/material/ListItemButton';
import ListItemText from '@mui/material/ListItemText';
import Toolbar from '@mui/material/Toolbar';
import { setCurrentIndex, setCurrentLyric, setCurrentBlob } from "./business/recorderSlice.js"
import yzs from "./business/request.js";

const drawerWidth = 240;

export default function () {
    const dispatch = useDispatch();
    const accessToken = useSelector(state => state.user.accessToken);
    const currentIndex = useSelector(state => state.recorder.currentIndex);
    const recordList = useSelector(state => state.recorder.list);
    const onSelected = (event, index) => {
        console.log("onSelected", index, recordList.at(index).transResultUrl)
        dispatch(setCurrentIndex(index));
        yzs.download(accessToken, recordList.at(index).transResultUrl).then(
            blob => blob.text()
        ).then(text => {
            console.log(text);
            let payload = recordList.at(index).type === 1 ? JSON.parse(text) : text;
            dispatch(setCurrentLyric(payload));
        });
        yzs.download(accessToken, recordList.at(index).audioUrl).then(blob => {
            dispatch(setCurrentBlob(URL.createObjectURL(blob)));
        });
    }
    return <Drawer
        variant="permanent"
        sx={{
            width: drawerWidth,
            flexShrink: 0,
            [`& .MuiDrawer-paper`]: { width: drawerWidth, boxSizing: 'border-box' },
        }}
    >
        <Toolbar />
        <Box sx={{ overflow: 'auto' }}>
            <List>
                {recordList === undefined ? <React.Fragment /> : recordList.map((item, index) => (
                    <ListItem key={index} disablePadding>
                        <ListItemButton selected={currentIndex === index} onClick={(event) => onSelected(event, index)}>
                            <ListItemText primary={item.editName} secondary={
                                <React.Fragment>
                                    <div>{item.content.slice(0, 50) + '......'}</div>
                                    <div>更新于 {new Date(item.createTime).toLocaleString()}</div>
                                </React.Fragment>
                            } />
                        </ListItemButton>
                    </ListItem>
                ))}
            </List>
        </Box>
    </Drawer>
}